# mkdocs-gallery

*[Sphinx-Gallery](https://sphinx-gallery.github.io/) features for [mkdocs](https://www.mkdocs.org/) (no [Sphinx](sphinx-doc.org/) dependency !).*

[![Python versions](https://img.shields.io/pypi/pyversions/mkdocs-gallery.svg)](https://pypi.python.org/pypi/mkdocs-gallery/) [![Build Status](https://github.com/smarie/mkdocs-gallery/actions/workflows/base.yml/badge.svg)](https://github.com/smarie/mkdocs-gallery/actions/workflows/base.yml) [![Tests Status](https://smarie.github.io/mkdocs-gallery/reports/junit/junit-badge.svg?dummy=8484744)](https://smarie.github.io/mkdocs-gallery/reports/junit/report.html) [![Coverage Status](https://smarie.github.io/mkdocs-gallery/reports/coverage/coverage-badge.svg?dummy=8484744)](https://smarie.github.io/mkdocs-gallery/reports/coverage/index.html) [![codecov](https://codecov.io/gh/smarie/mkdocs-gallery/branch/main/graph/badge.svg)](https://codecov.io/gh/smarie/mkdocs-gallery) [![Flake8 Status](https://smarie.github.io/mkdocs-gallery/reports/flake8/flake8-badge.svg?dummy=8484744)](https://smarie.github.io/mkdocs-gallery/reports/flake8/index.html)

[![Documentation](https://img.shields.io/badge/doc-latest-blue.svg)](https://smarie.github.io/mkdocs-gallery/) [![PyPI](https://img.shields.io/pypi/v/mkdocs-gallery.svg)](https://pypi.python.org/pypi/mkdocs-gallery/) [![Downloads](https://pepy.tech/badge/mkdocs-gallery)](https://pepy.tech/project/mkdocs-gallery) [![Downloads per week](https://pepy.tech/badge/mkdocs-gallery/week)](https://pepy.tech/project/mkdocs-gallery) [![GitHub stars](https://img.shields.io/github/stars/smarie/mkdocs-gallery.svg)](https://github.com/smarie/mkdocs-gallery/stargazers) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5786851.svg)](https://doi.org/10.5281/zenodo.5786851)

Do you love [Sphinx-Gallery](https://sphinx-gallery.github.io/) but prefer [mkdocs](https://www.mkdocs.org/) over [Sphinx](sphinx-doc.org/) for your documentation ? `mkdocs-gallery` was written for you ;) 

It relies on [mkdocs-material](https://squidfunk.github.io/mkdocs-material) to get the most of mkdocs, so that your galleries look nice!

The documentation for users is available here: [https://smarie.github.io/mkdocs-gallery/](https://smarie.github.io/mkdocs-gallery/)

A readme for developers is available here: [https://github.com/smarie/mkdocs-gallery](https://github.com/smarie/mkdocs-gallery)
